@@ -2,19 +2,18 @@ import os
 import posixpath
 from fnmatch import fnmatchcase
 
-import datatree
 import fsspec
 import xarray as xr
 from fsspec.implementations.dirfs import DirFileSystem
 from tlz.dicttoolz import valmap
 from tlz.functoolz import compose_left, curry, juxt
 
-from .calibrations import read_noise_levels
-from .manifest import read_manifest
-from .product.reader import read_product
-from .product.transformers import extract_dataset
-from .product.utils import starcall
-from .xml import read_xml
+from safe_rcm.calibrations import read_noise_levels
+from safe_rcm.manifest import read_manifest
+from safe_rcm.product.reader import read_product
+from safe_rcm.product.transformers import extract_dataset
+from safe_rcm.product.utils import starcall
+from safe_rcm.xml import read_xml
 
 try:
     ExceptionGroup
@@ -128,6 +127,7 @@ def open_rcm(
                 lambda arr: arr.set_index({"stacked": ["sarCalibrationType", "pole"]}),
                 lambda arr: arr.unstack("stacked"),
                 lambda arr: arr.rename("lookup_tables"),
+                lambda arr: arr.to_dataset(),
             ),
         },
         "/noiseLevels": {
@@ -160,7 +160,7 @@ def open_rcm(
 
     return tree.assign(
         {
-            "lookupTables": datatree.DataTree.from_dict(calibration),
-            "imagery": datatree.DataTree(imagery),
+            "lookupTables": xr.DataTree.from_dict(calibration),
+            "imagery": xr.DataTree(imagery),
         }
     )
