@@ -1,14 +1,13 @@
-import datatree
 import xarray as xr
 from tlz.dicttoolz import keyfilter, merge, merge_with, valfilter, valmap
 from tlz.functoolz import compose_left, curry, juxt
 from tlz.itertoolz import first, second
 
-from ..xml import read_xml
-from . import transformers
-from .dicttoolz import keysplit, query
-from .predicates import disjunction, is_nested_array, is_scalar_valued
-from .utils import dictfirst, starcall
+from safe_rcm.product import transformers
+from safe_rcm.product.dicttoolz import keysplit, query
+from safe_rcm.product.predicates import disjunction, is_nested_array, is_scalar_valued
+from safe_rcm.product.utils import dictfirst, starcall
+from safe_rcm.xml import read_xml
 
 
 @curry
@@ -276,4 +275,4 @@ def read_product(mapper, product_path):
         lambda x: execute(**x)(decoded),
         layout,
     )
-    return datatree.DataTree.from_dict(converted)
+    return xr.DataTree.from_dict(converted)
